@@ -113,6 +113,9 @@ def add_log_options(parser):
     group.add_option("--log-dir", default=None,
                       help="(Optional) The directory to keep log files in "
                            "(will be prepended to --logfile)")
+    group.add_option('--use-syslog', default=False, dest="use_syslog",
+                     action="store_true",
+                     help="Use syslog for logging.")
     parser.add_option_group(group)
 
 
@@ -135,8 +138,10 @@ def setup_logging(options, conf):
 
     # If either the CLI option or the conf value
     # is True, we set to True
-    debug = options.get('debug') or conf.get('debug', False)
-    verbose = options.get('verbose') or conf.get('verbose', False)
+    debug = options.get('debug') or \
+            get_option(conf, 'debug', type='bool', default=False)
+    verbose = options.get('verbose') or \
+            get_option(conf, 'verbose', type='bool', default=False)
     root_logger = logging.root
     if debug:
         root_logger.setLevel(logging.DEBUG)
@@ -157,30 +162,33 @@ def setup_logging(options, conf):
     if not logfile:
         logfile = conf.get('log_file')
 
-    if logfile:
+    use_syslog = options.get('use_syslog') or \
+                get_option(conf, 'use_syslog', type='bool', default=False)
+
+    if use_syslog:
+        handler = logging.handlers.SysLogHandler(address='/dev/log')
+    elif logfile:
         logdir = options.get('log_dir')
         if not logdir:
             logdir = conf.get('log_dir')
         if logdir:
             logfile = os.path.join(logdir, logfile)
-        logfile = logging.FileHandler(logfile)
-        logfile.setFormatter(formatter)
-        logfile.setFormatter(formatter)
-        root_logger.addHandler(logfile)
+        handler = logging.FileHandler(logfile)
     else:
         handler = logging.StreamHandler(sys.stdout)
-        handler.setFormatter(formatter)
-        root_logger.addHandler(handler)
+
+    handler.setFormatter(formatter)
+    root_logger.addHandler(handler)
 
 
-def find_config_file(options, args):
+def find_config_file(app_name, options, args):
     """
-    Return the first config file found.
+    Return the first config file found for an application.
 
     We search for the paste config file in the following order:
     * If --config-file option is used, use that
     * If args[0] is a file, use that
-    * Search for glance.conf in standard directories:
+    * Search for $app.conf in standard directories:
         * .
         * ~.glance/
         * ~
@@ -198,7 +206,7 @@ def find_config_file(options, args):
         if os.path.exists(args[0]):
             return fix_path(args[0])
 
-    # Handle standard directory search for glance.conf
+    # Handle standard directory search for $app_name.conf
     config_file_dirs = [fix_path(os.getcwd()),
                         fix_path(os.path.join('~', '.glance')),
                         fix_path('~'),
@@ -206,7 +214,7 @@ def find_config_file(options, args):
                         '/etc']
 
     for cfg_dir in config_file_dirs:
-        cfg_file = os.path.join(cfg_dir, 'glance.conf')
+        cfg_file = os.path.join(cfg_dir, '%s.conf' % app_name)
         if os.path.exists(cfg_file):
             return cfg_file
 
@@ -219,7 +227,7 @@ def load_paste_config(app_name, options, args):
     We search for the paste config file in the following order:
     * If --config-file option is used, use that
     * If args[0] is a file, use that
-    * Search for glance.conf in standard directories:
+    * Search for $app_name.conf in standard directories:
         * .
         * ~.glance/
         * ~
@@ -236,7 +244,7 @@ def load_paste_config(app_name, options, args):
     :raises RuntimeError when config file cannot be located or there was a
             problem loading the configuration file.
     """
-    conf_file = find_config_file(options, args)
+    conf_file = find_config_file(app_name, options, args)
     if not conf_file:
         raise RuntimeError("Unable to locate any configuration file. "
                             "Cannot load application %s" % app_name)
@@ -255,7 +263,7 @@ def load_paste_app(app_name, options, args):
     We search for the paste config file in the following order:
     * If --config-file option is used, use that
     * If args[0] is a file, use that
-    * Search for glance.conf in standard directories:
+    * Search for $app_name.conf in standard directories:
         * .
         * ~.glance/
         * ~
@@ -278,8 +286,10 @@ def load_paste_app(app_name, options, args):
 
         # We only update the conf dict for the verbose and debug
         # flags. Everything else must be set up in the conf file...
-        debug = options.get('debug') or conf.get('debug', False)
-        verbose = options.get('verbose') or conf.get('verbose', False)
+        debug = options.get('debug') or \
+                get_option(conf, 'debug', type='bool', default=False)
+        verbose = options.get('verbose') or \
+                get_option(conf, 'verbose', type='bool', default=False)
         conf['debug'] = debug
         conf['verbose'] = verbose
 
