@@ -1,4 +1,6 @@
-# Copyright 2011 OpenStack Foundation
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright 2011 OpenStack, LLC
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -15,51 +17,65 @@
 
 """Functional test case that tests logging output"""
 
-import http.client as http
+import httplib2
 import os
 import stat
-
-import httplib2
+import unittest
 
 from glance.tests import functional
+from glance.tests.utils import execute
 
 
 class TestLogging(functional.FunctionalTest):
 
     """Functional tests for Glance's logging output"""
 
-    def test_debug(self):
+    def test_verbose_debug(self):
         """
-        Test logging output proper when debug is on.
+        Test logging output proper when verbose and debug
+        is on.
         """
         self.cleanup()
         self.start_servers()
 
-        # The default functional test case has both debug on. Let's verify
-        # that debug statements appear in the API logs.
+        # The default functional test case has both verbose
+        # and debug on. Let's verify that debug statements
+        # appear in both the API and registry logs.
 
         self.assertTrue(os.path.exists(self.api_server.log_file))
 
-        with open(self.api_server.log_file, 'r') as f:
-            api_log_out = f.read()
+        api_log_out = open(self.api_server.log_file, 'r').read()
 
-        self.assertIn('DEBUG glance', api_log_out)
+        self.assertTrue('DEBUG [glance-api]' in api_log_out)
+
+        self.assertTrue(os.path.exists(self.registry_server.log_file))
+
+        registry_log_out = open(self.registry_server.log_file, 'r').read()
+
+        self.assertTrue('DEBUG [glance-registry]' in registry_log_out)
 
         self.stop_servers()
 
-    def test_no_debug(self):
+    def test_no_verbose_no_debug(self):
         """
-        Test logging output proper when debug is off.
+        Test logging output proper when verbose and debug
+        is off.
         """
         self.cleanup()
-        self.start_servers(debug=False)
+        self.start_servers(debug=False, verbose=False)
 
         self.assertTrue(os.path.exists(self.api_server.log_file))
 
-        with open(self.api_server.log_file, 'r') as f:
-            api_log_out = f.read()
+        api_log_out = open(self.api_server.log_file, 'r').read()
+
+        self.assertFalse('DEBUG [glance-api]' in api_log_out)
+
+        self.assertTrue(os.path.exists(self.registry_server.log_file))
+
+        registry_log_out = open(self.registry_server.log_file, 'r').read()
+
+        self.assertFalse('DEBUG [glance-registry]' in registry_log_out)
 
-        self.assertNotIn('DEBUG glance', api_log_out)
         self.stop_servers()
 
     def assertNotEmptyFile(self, path):
@@ -77,9 +93,9 @@ class TestLogging(functional.FunctionalTest):
 
         os.rename(self.api_server.log_file, self.api_server.log_file + ".1")
 
-        path = "http://%s:%d/" % ("127.0.0.1", self.api_port)
+        path = "http://%s:%d/" % ("0.0.0.0", self.api_port)
         response, content = httplib2.Http().request(path, 'GET')
-        self.assertEqual(http.MULTIPLE_CHOICES, response.status)
+        self.assertEqual(response.status, 300)
 
         self.assertNotEmptyFile(self.api_server.log_file)
 
